@@ -225,6 +225,71 @@ macro_rules! query_filter {
     );
 }
 
+#[allow(unused_macros)]
+macro_rules! creation_field {
+
+    ($(#[$attr:meta])* $set_func:ident, $with_func:ident -> $name:ident) => (
+        $(#[$attr])*
+        #[inline]
+        pub fn $set_func<S: Into<String>>(&mut self, value: S)  {
+            self.$name = value.into();
+        }
+
+        $(#[$attr])*
+        #[inline]
+        pub fn $with_func<S: Into<String>>(mut self, value: S) -> Self {
+            self.$set_func(value);
+            self
+        }
+    );
+
+    ($(#[$attr:meta])* $set_func:ident, $with_func:ident -> $name:ident: $type:ty) => (
+        $(#[$attr])*
+        #[inline]
+        pub fn $set_func(&mut self, value: $type)  {
+            self.$name = value;
+        }
+
+        $(#[$attr])*
+        #[inline]
+        pub fn $with_func(mut self, value: $type) -> Self {
+            self.$set_func(value);
+            self
+        }
+    );
+
+    ($(#[$attr:meta])* $set_func:ident, $with_func:ident -> $name:ident: optional String) => (
+        $(#[$attr])*
+        #[inline]
+        pub fn $set_func<S: Into<String>>(&mut self, value: S)  {
+            self.$name = Some(value.into());
+        }
+
+        $(#[$attr])*
+        #[inline]
+        pub fn $with_func<S: Into<String>>(mut self, value: S) -> Self {
+            self.$set_func(value);
+            self
+        }
+    );
+
+    ($(#[$attr:meta])* $set_func:ident, $with_func:ident -> $name:ident: optional $type:ty) => (
+        $(#[$attr])*
+        #[inline]
+        pub fn $set_func(&mut self, value: $type)  {
+            self.$name = Some(value);
+        }
+
+        $(#[$attr])*
+        #[inline]
+        pub fn $with_func(mut self, value: $type) -> Self {
+            self.$set_func(value);
+            self
+        }
+    );
+
+}
+
 #[allow(unused_macros)]
 macro_rules! creation_inner_field {
 
@@ -333,6 +398,27 @@ macro_rules! creation_inner_vec {
         }
     );
 
+    ($(#[$attr:meta])* $add_func:ident, $with_func:ident -> $name:ident: into $type:ty) => (
+        $(#[$attr])*
+        pub fn $add_func<S: Into<$type>>(&mut self, value: S)  {
+            self.inner.$name.push(value.into());
+        }
+
+        $(#[$attr])*
+        #[inline]
+        pub fn $name(&mut self) -> &mut Vec<$type> {
+            &mut self.inner.$name
+        }
+
+        $(#[$attr])*
+        #[inline]
+        pub fn $with_func<S: Into<$type>>(mut self, value: S) -> Self {
+            self.$add_func(value);
+            self
+        }
+    );
+
+
 }
 
 #[allow(unused_macros)]
@@ -574,6 +660,8 @@ pub mod compute;
 pub mod image;
 #[cfg(feature = "network")]
 pub mod network;
+#[cfg(feature = "object-storage")]
+pub mod object_storage;
 /// Reimport of the synchronous session from `osauth`.
 ///
 /// See [osauth documentation](https://docs.rs/osauth/) for details.
