@@ -25,7 +25,8 @@ pub use self::floatingips::{FloatingIp, FloatingIpQuery, NewFloatingIp};
 pub use self::networks::{Network, NetworkQuery, NewNetwork};
 pub use self::ports::{NewPort, Port, PortIpAddress, PortIpRequest, PortQuery};
 pub use self::protocol::{
-    AllocationPool, FloatingIpSortKey, FloatingIpStatus, HostRoute, IpVersion, Ipv6Mode,
-    NetworkSortKey, NetworkStatus, PortExtraDhcpOption, PortForwarding, PortSortKey, SubnetSortKey,
+    AllocationPool, AllowedAddressPair, FloatingIpSortKey, FloatingIpStatus, HostRoute, IpVersion,
+    Ipv6Mode, NetworkSortKey, NetworkStatus, PortExtraDhcpOption, PortForwarding, PortSortKey,
+    SubnetSortKey,
 };
 pub use self::subnets::{NewSubnet, Subnet, SubnetQuery};
